==> pan-0.6.5.tar.bz2: pan-0.6.5/pan/article-db.h <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999  Matt Eagleson (e.Messiah@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __ARTICLE_HEADERS_DB_H__
#define __ARTICLE_HEADERS_DB_H__

typedef struct AHDB* article_db;

extern article_db ahdb_ref ( const server_data*, const group_data* );
extern void ahdb_unref ( article_db );

extern article_data* ahdb_get ( article_db, const char* message_id );
extern GSList* ahdb_get_all ( article_db, GFunc, gpointer );

extern gboolean ahdb_exists ( const server_data*, const group_data* );
extern void ahdb_delete_db_file ( const server_data*, const group_data* );

extern void ahdb_save ( article_db, const article_data*, gboolean sync );
extern void ahdb_save_all ( article_db, GSList* article_headers, GFunc, gpointer );
extern void ahdb_erase ( article_db, const article_data* );
extern void ahdb_erase_all ( article_db );
extern void ahdb_sync ( article_db );

#endif

==> pan-0.6.6.tar.bz2: pan-0.6.6/pan/article-db.h <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999  Matt Eagleson (e.Messiah@superpimp.org)
 * article-db (C) 1999 Charles Kerr (charles@skywalker.ecn.ou.edu)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __ARTICLE_HEADERS_DB_H__
#define __ARTICLE_HEADERS_DB_H__

/* NOTE: If the field order in ahdb changes, these
 * values need to be updated to match */
#define AHDB_FIELD_DATE 0
#define AHDB_FIELD_STATE 1
#define AHDB_FIELD_LINECOUNT 2
#define AHDB_FIELD_PARTS 3
#define AHDB_FIELD_PART 4
#define AHDB_FIELD_NUMBER 5
#define AHDB_FIELD_SUBJECT 6
#define AHDB_FIELD_AUTHOR 7
#define AHDB_FIELD_REFERENCES 8
#define AHDB_FIELD_NEWSGROUPS 9
#define AHDB_FIELD_FOLLOWUP_TO 10

typedef struct AHDB* article_db;

extern article_db ahdb_ref ( const server_data*, const group_data* );
extern void ahdb_unref ( article_db );

extern article_data* ahdb_get ( article_db, const char* message_id );
extern GSList* ahdb_get_all ( article_db, GFunc, gpointer );

extern gboolean ahdb_exists ( const server_data*, const group_data* );
extern void ahdb_delete_db_file ( const server_data*, const group_data* );

extern void ahdb_save ( article_db, const article_data*, gboolean sync );
extern void ahdb_save_all ( article_db, GSList* article_headers, GFunc, gpointer );
extern void ahdb_erase ( article_db, const article_data*, const char *);
extern void ahdb_erase_all ( article_db );
extern void ahdb_sync ( article_db );
extern void ahdb_foreach (article_db, DBFunc, gpointer);
extern const char * ahdb_field (const char *, int);

#endif
